#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_ARECROSSCOMPATIBLE_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_ARECROSSCOMPATIBLE_HPP_INCLUDED

#include <nt2/predicates/include/functions/scalar/arecrosscompatible.hpp>

#endif
